@@ -128,6 +128,13 @@ class Instance(contextlib.AbstractContextManager):
             and obj.services == self.services
         )
 
+    def __str__(self):
+        """Human readable description."""
+        return (
+            f"Instance(name: {self.name}, definition: {self.definition_name}, ready: {self.ready},"
+            f" status_message: {self.status_message}, services: {self.services})"
+        )
+
     @staticmethod
     def _create(definition_name: str, stub: ProductInstanceManagerStub, timeout: float = None):
         """Create a product instance from the given definition.
@@ -263,6 +270,11 @@ class Instance(contextlib.AbstractContextManager):
                 Product:             Ansys Mechanical Enterprise
                 MAPDL Version:       22.1
                 ansys.mapdl Version: 0.61.2
+
+            If the service exposes multiple ports, this method can be used to
+            connect to another port by providing the service name:
+
+            >>> filemanagement_channel=instance.build_grpc_channel(service_name="filemanagement")
         """
         if not self.ready:
             raise InstanceNotReadyError(self.name)
